﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:docs="http://tempuri.org/docs"
               xmlns:msxsl="urn:schemas-microsoft-com:xslt"
               xmlns:ix="urn:RevisableObjectImportTemplate.xsd"
               exclude-result-prefixes="msxsl docs"
               xmlns:myScript="urn:my-scripts">

  <docs:transformationMetaData>
    <docs:name>Object Size Analyzer</docs:name>
    <docs:description>Lists the byte size if each Document Object. Large objects are marked red. Shall NOT use 'Convert RTF to plain text'.</docs:description>
    <docs:extension>.html</docs:extension>
    <docs:onlyAsPlaintext>false</docs:onlyAsPlaintext>
  </docs:transformationMetaData>
  
  <xsl:output method="html" indent="yes"/>


  <msxsl:script language="C#" implements-prefix="myScript">
    public string Max(string var)
    {
    string[] vals = var.Split(',');

    int max = 0;
    foreach(string val in vals)
    {
    if (val.Length > 0)
    {
    int curVal = int.Parse(val);
    if (curVal> max)
    {
    max = curVal;
    }
    }
    }
    //convert to size
    double kb = Math.Round( (max / 1024f) , 1);
    double mb = Math.Round( (max / 1024f) / 1024f, 1);

    if (mb > 0)
    {
      return string.Format("{0} mb", mb);
    }

    return string.Format("{0} kb", kb);
  }

  </msxsl:script>

  <xsl:template match="ix:DocumentObjects">
    <html>
      <body>
        <h2>Document Object Size summary</h2>
        <table border="1">
          <tr bgcolor="#9acd32">
            <th>Type Name</th>
            <th>Project</th>
            <th>ID</th>
            <th>Max attribute length</th>
          </tr>
          <!--select distinct typenames-->
          <xsl:for-each select="ix:DocumentObject">
            <xsl:variable name="maxLength">
              <xsl:call-template name="getLength">
                <xsl:with-param name="projectName" select="@ProjectName"/>
                <xsl:with-param name="id" select="@ID"/>
              </xsl:call-template>
            </xsl:variable>
            <xsl:variable name="backcolor">
              <xsl:choose>
                <xsl:when test="contains($maxLength, 'mb')">#ff00ff</xsl:when>
                <xsl:otherwise>#9acd32</xsl:otherwise>
              </xsl:choose>/>
            </xsl:variable>
            <tr>
              <td>
                <xsl:value-of select="@TypeName"/>
              </td>
              <td>
                <xsl:value-of select="@ProjectName"/>
              </td>
              <td>
                <xsl:value-of select="@ID"/>
              </td>
              <xsl:choose>
                <xsl:when test="contains($maxLength, 'mb')">
                  <td bgcolor="red" >
                    <xsl:value-of select="$maxLength"/>
                  </td>
                </xsl:when>
                <xsl:otherwise>
                  <td>
                    <xsl:value-of select="$maxLength"/>
                  </td>
                </xsl:otherwise>
              </xsl:choose>
            </tr>
          </xsl:for-each>
        </table>
      </body>
    </html>
  </xsl:template>

  <xsl:template name="getLength">
    <xsl:param name="projectName"/>
    <xsl:param name="id"/>
    <xsl:variable name="lengths">
      <xsl:for-each select="//ix:DocumentObjects/ix:DocumentObject[@ProjectName=$projectName][@ID=$id]/ix:Attributes/ix:Attribute">
        <xsl:value-of select="concat(string-length(),',')"/>
      </xsl:for-each>
    </xsl:variable>
    <xsl:value-of select="myScript:Max($lengths)"/>
  </xsl:template>
</xsl:stylesheet>
