<?xml version="1.0"?>
<xsl:stylesheet version = "1.0" xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" xmlns:docs="http://tempuri.org/docs" xmlns:ix="urn:RevisableObjectImportTemplate.xsd" xmlns:myScript="urn:my-scripts" exclude-result-prefixes="docs" xmlns:msxsl="urn:schemas-microsoft-com:xslt">
  <docs:transformationMetaData>
    <docs:name>CSV Transformation</docs:name>
    <docs:description>CSV file containing all attributes except Table and Array Attributes. Includes IDs of incoming and outgoing traces</docs:description>
    <docs:extension>.csv</docs:extension>
    <docs:onlyAsPlaintext>true</docs:onlyAsPlaintext>
  </docs:transformationMetaData>
  <xsl:output method="text"/>
  <msxsl:script language="C#" implements-prefix="myScript">
    public string StringToCSV(string token)
    {
    token = token.Trim(new char[]{'\r','\n'});
    token = token.Trim();
    token = token.Replace("\"", "\"\"");
    if (token.Contains(",") || token.Contains("\"") || token.Contains("\n") || token.Contains("\r"))
    {
    return "\"" + token + "\"";
    }
    return token;
    }
  </msxsl:script>
  <xsl:template name="Header" match="ix:DocumentObjects">
    <!--create a header-->
    <xsl:text>Project Name;Id;Title;Outgoing Traces;IncomingTraces;</xsl:text>
    <xsl:for-each select="ix:DocumentObject[1]/ix:Attributes[1]/ix:Attribute[@AttributeType != 'TableAttribute' and @AttributeType != 'ArrayAttribute']">
      <xsl:value-of select="@AttributeName"/>
      <xsl:if test="position() != last()">
        <xsl:text>;</xsl:text>
      </xsl:if>
    </xsl:for-each>
    <!--line break after last attribute header-->
    <xsl:text>&#xa;</xsl:text>
    <!--run the rest of the templates-->
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template name="DocumentObjectsToCSV" match="ix:DocumentObject">
    <xsl:value-of select="myScript:StringToCSV(@ProjectName)"/>
    <xsl:text>;</xsl:text>
    <xsl:value-of select="myScript:StringToCSV(@ID)"/>
    <xsl:text>;</xsl:text>
    <xsl:value-of select="myScript:StringToCSV(@Title)"/>
    <xsl:text>;</xsl:text>
    <xsl:for-each select= "ix:Traces/ix:Trace/text()">
      <xsl:value-of select="." disable-output-escaping="yes"/>
      <xsl:if test="not(position() = last())">
        <xsl:text disable-output-escaping="yes">,</xsl:text>
      </xsl:if>
    </xsl:for-each>
          <xsl:text>;</xsl:text>
    <xsl:for-each select= "ix:IncomingTraces/ix:IncomingTrace/text()">
      <xsl:value-of select="." disable-output-escaping="yes"/>
      <xsl:if test="not(position() = last())">
        <xsl:text disable-output-escaping="yes">,</xsl:text>
      </xsl:if>
    </xsl:for-each>
    <xsl:text>;</xsl:text>
    <!--get all attributes except tables-->
    <xsl:for-each select="ix:Attributes/ix:Attribute[@AttributeType != 'TableAttribute' and @AttributeType != 'ArrayAttribute']">
      <xsl:value-of select="myScript:StringToCSV(.)"/>
      <xsl:if test="position() != last()">
        <xsl:text>;</xsl:text>
      </xsl:if>
    </xsl:for-each>
    <!--line break after last attribute-->
    <xsl:text>&#xa;</xsl:text>
  </xsl:template>
</xsl:stylesheet>